@@ -7,17 +7,15 @@
 #include "blinken.h"
 
 #include <QCursor>
-#include <QEvent>
 #include <QPainter>
 #include <QSvgRenderer>
 #include <QTimer>
-#include <QAction>
 #include <QApplication>
 #include <QInputDialog>
 #include <QKeySequence>
 #include <QMouseEvent>
+#include <QAction>
 
-#include <KConfig>
 #include <KHelpMenu>
 #include <KFontUtils>
 #include <KLocalizedString>
@@ -40,7 +38,7 @@ static const double nonButtonRibbonY = 125.0;
 
 blinken::blinken() : m_overHighscore(false), m_overQuit(false), m_overCentralText(false), m_overMenu(false), m_overAboutKDE(false), m_overAboutBlinken(false), m_overSettings(false), m_overManual(false), m_overCentralLetters(false), m_overCounter(false), m_overFont(false), m_overSound(false), m_showPreferences(false), m_updateButtonHighlighting(false), m_highlighted(blinkenGame::none)
 {
-	m_renderer = new QSvgRenderer(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("images/blinken.svg")));
+	m_renderer = new QSvgRenderer(QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("images/blinken.svg")));
 	
 	m_buttons[0] = new button(blinkenGame::blue);
 	m_buttons[1] = new button(blinkenGame::yellow);
@@ -345,8 +343,8 @@ void blinken::mousePressEvent(QMouseEvent *e)
 {
 	if (m_overHighscore || m_overCounter)
 	{
-		highScoreDialog *hsd = new highScoreDialog(this, m_renderer);
-		hsd->showLevel(1);
+		highScoreDialog hsd(this, m_renderer);
+		hsd.showLevel(1);
 		m_updateButtonHighlighting = true;
 	}
 	else if (m_showPreferences && m_fontRect.contains(e -> pos()) && !m_alwaysUseNonCoolFont)
@@ -418,8 +416,8 @@ void blinken::checkHS()
 			m_lastName = name;
 			hsm.addScore(m_game.level(), m_game.score(), name);
 		}
-		highScoreDialog *hsd = new highScoreDialog(this, m_renderer);
-		hsd->showLevel(m_game.level());
+		highScoreDialog hsd(this, m_renderer);
+		hsd.showLevel(m_game.level());
 	}
 }
 
